import { defineComponent, onMounted, reactive, ref } from 'vue'
import styles from './video.module.less'
import poster from './images/video_bg.png'
import { Button, Loading } from 'vant'
import { browser } from '@/helpers/utils'
import Plyr from 'plyr'
import 'plyr/dist/plyr.css'
import { useInterval, useIntervalFn } from '@vueuse/core'

export default defineComponent({
  name: 'pre-register',
  setup() {
    // 播放视频总时长
    const videoInterval = useInterval(1000, { controls: true })
    videoInterval.pause()

    console.log(videoInterval)
    // 间隔多少时间同步数据
    // const { pause, resume, isActive } = useIntervalFn(() => {
    // }, 10000)
    const forms = reactive({
      loading: true,
      player: null as any
    })

    const _init = () => {
      const controls = [
        'play-large',
        'play',
        'progress',
        'captions',
        'current-time',
        'duration',
        'settings',
        'fullscreen'
      ]
      const params: any = {
        controls: controls,
        settings: ['speed'],
        speed: { selected: 1, options: [0.5, 1, 1.5, 2] },
        i18n: {
          speed: '速度',
          normal: '默认'
        },
        invertTime: false
      }

      if (browser().iPhone) {
        params.fullscreen = {
          enabled: true,
          fallback: 'force',
          iosNative: true
        }
      }

      forms.player = new Plyr('#register-video', params)

      forms.player.on('loadedmetadata', () => {
        forms.loading = false
      })

      //
      // forms.player.on('seeking', (val: any) => {
      //   console.log('seeking')
      // })

      // // 拖动结束时
      // forms.player.on('seeked', (val: any) => {
      //   console.log('seeked')
      // })

      // 正在搜索中
      forms.player.on('waiting', () => {
        console.log('waiting')
        videoInterval.pause()
      })

      // 如何视频在缓存不会触发
      forms.player.on('timeupdate', () => {
        console.log('timeupdate', forms.player.currentTime)

        // 判断视频计时器是否暂停，如果暂停则恢复
        !videoInterval.isActive.value && videoInterval.resume()
      })

      // 开始播放
      forms.player.on('play', () => {
        console.log('play')
        // 判断视频计时器是否暂停，如果暂停则恢复
        !videoInterval.isActive.value && videoInterval.resume()
      })

      // 暂停播放
      forms.player.on('pause', () => {
        console.log('pause')

        videoInterval.pause()
      })
    }

    onMounted(() => {
      _init()
    })
    return () => (
      <div class={styles['pre-register-video']}>
        <div class={styles.videoContainer}>
          <div class={styles['video-content']}>
            <video
              id="register-video"
              class={styles['video']}
              src={'https://daya.ks3-cn-beijing.ksyun.com/202105/SWmqmvW.mp4?time' + Date.now()}
              playsinline={true}
              poster={poster}
              preload="auto"
            ></video>
            {/* 加载视频使用 */}
            {forms.loading && (
              <div class={styles.loadingVideo}>
                <Loading
                  size={36}
                  color="#FF8057"
                  vertical
                  style={{ height: '100%', justifyContent: 'center' }}
                >
                  加载中...
                </Loading>
              </div>
            )}
          </div>
        </div>

        <div class={styles.messageContainer}>
          <div class={styles.messageContent}>
            <p>家长您好！</p>
            <p class={styles.c1}>
              学校管乐团正式筹备组建。请家长们合理安排时间观看家长会视频。并在明晚20:00前，进行意向确认（不想参与的，勾选“无意向”即可）。
            </p>
            <p class={styles.c1}>
              下周，专业老师将针对意向入团学员进行身体条件确认。谢谢各位的支持！
            </p>

            <p class={styles.bottom}>
              <span>注：</span>乐团于<span>下学期</span>正式开始训练，训练时间下学期开学前另行通知，
              <span>训练时间会与学校相关社团时间错开</span>，家长无需担心时间冲突问题。
            </p>
          </div>

          <Button class={styles.submitBtn}></Button>
        </div>
      </div>
    )
  }
})
